# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .chunk_metadata_page_range import ChunkMetadataPageRange


class ChunkMetadata(UncheckedBaseModel):
    """
    Metadata about the chunk.
    """

    page_range: typing_extensions.Annotated[ChunkMetadataPageRange, FieldMetadata(alias="pageRange")] = pydantic.Field()
    """
    The page range this chunk covers. Often will just be a partial page, in which cases `start` and `end` will be the same.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
