# This file was auto-generated by Fern from our API Definition.

import typing

ExtractionFieldType = typing.Union[
    typing.Literal["string", "number", "currency", "boolean", "date", "array", "enum", "object", "signature"],
    typing.Any,
]
