# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventProcessorEventType = typing.Union[
    typing.Literal["processor.created", "processor.updated", "processor.deleted", "processor.draft.updated"], typing.Any
]
