# This file was auto-generated by Fern from our API Definition.

import typing

from .classifier_output import ClassifierOutput
from .extraction_output import ExtractionOutput
from .splitter_output import SplitterOutput

ProcessorOutput = typing.Union[ExtractionOutput, ClassifierOutput, SplitterOutput]
