# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ProcessorCreateRequestConfig,
    ProcessorCreateRequestConfig_Classify,
    ProcessorCreateRequestConfig_Extract,
    ProcessorCreateRequestConfig_Splitter,
    ProcessorCreateResponse,
    ProcessorUpdateRequestConfig,
    ProcessorUpdateRequestConfig_Classify,
    ProcessorUpdateRequestConfig_Extract,
    ProcessorUpdateRequestConfig_Splitter,
    ProcessorUpdateResponse,
)

__all__ = [
    "ProcessorCreateRequestConfig",
    "ProcessorCreateRequestConfig_Classify",
    "ProcessorCreateRequestConfig_Extract",
    "ProcessorCreateRequestConfig_Splitter",
    "ProcessorCreateResponse",
    "ProcessorUpdateRequestConfig",
    "ProcessorUpdateRequestConfig_Classify",
    "ProcessorUpdateRequestConfig_Extract",
    "ProcessorUpdateRequestConfig_Splitter",
    "ProcessorUpdateResponse",
]
