# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventWorkflowRunEventType = typing.Union[
    typing.Literal[
        "workflow_run.completed",
        "workflow_run.failed",
        "workflow_run.needs_review",
        "workflow_run.rejected",
        "workflow_run.step_run.processed",
    ],
    typing.Any,
]
