# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .processor_version_create_request_config import (
    ProcessorVersionCreateRequestConfig,
    ProcessorVersionCreateRequestConfig_Classify,
    ProcessorVersionCreateRequestConfig_Extract,
    ProcessorVersionCreateRequestConfig_Splitter,
)
from .processor_version_create_request_release_type import ProcessorVersionCreateRequestReleaseType
from .processor_version_create_response import ProcessorVersionCreateResponse
from .processor_version_get_response import ProcessorVersionGetResponse
from .processor_version_list_response import ProcessorVersionListResponse

__all__ = [
    "ProcessorVersionCreateRequestConfig",
    "ProcessorVersionCreateRequestConfig_Classify",
    "ProcessorVersionCreateRequestConfig_Extract",
    "ProcessorVersionCreateRequestConfig_Splitter",
    "ProcessorVersionCreateRequestReleaseType",
    "ProcessorVersionCreateResponse",
    "ProcessorVersionGetResponse",
    "ProcessorVersionListResponse",
]
