# This file was auto-generated by Fern from our API Definition.

import typing

from .provided_extraction_field_result import ProvidedExtractionFieldResult

ProvidedFieldsArrayOutput = typing.Dict[str, ProvidedExtractionFieldResult]
