# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventProcessorRunEventType = typing.Union[
    typing.Literal["processor_run.processed", "processor_run.failed"], typing.Any
]
