# This file was auto-generated by Fern from our API Definition.

import typing

ParseErrorCode = typing.Union[
    typing.Literal[
        "INVALID_CONFIG_OPTIONS",
        "UNABLE_TO_DOWNLOAD_FILE",
        "FILE_TYPE_NOT_SUPPORTED",
        "FILE_SIZE_TOO_LARGE",
        "CORRUPT_FILE",
        "OCR_ERROR",
        "PASSWORD_PROTECTED_FILE",
        "FAILED_TO_CONVERT_TO_PDF",
        "FAILED_TO_GENERATE_TARGET_FORMAT",
        "INTERNAL_ERROR",
    ],
    typing.Any,
]
