# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .webhook_event_workflow_event_type import WebhookEventWorkflowEventType
from .workflow import Workflow


class WebhookEventWorkflow(UncheckedBaseModel):
    """
    Webhook event for workflow related events
    """

    event_type: typing_extensions.Annotated[
        typing.Optional[WebhookEventWorkflowEventType], FieldMetadata(alias="eventType")
    ] = None
    payload: typing.Optional[Workflow] = None
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field()
    """
    Unique identifier for the event
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
