# This file was auto-generated by Fern from our API Definition.

import typing

from .fields_array_output import FieldsArrayOutput
from .json_output import JsonOutput

ExtractionOutput = typing.Union[JsonOutput, FieldsArrayOutput]
