# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.processor_version import ProcessorVersion


class ProcessorVersionListResponse(UncheckedBaseModel):
    success: bool
    versions: typing.List[ProcessorVersion] = pydantic.Field()
    """
    An array of ProcessorVersion objects representing all versions of the specified processor.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from ...types.extraction_field import ExtractionField  # noqa: E402, F401, I001

update_forward_refs(ProcessorVersionListResponse)
