# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventEventType = typing.Union[
    typing.Literal[
        "workflow_run.completed",
        "workflow_run.failed",
        "workflow_run.needs_review",
        "workflow_run.rejected",
        "workflow_run.step_run.processed",
        "processor_run.processed",
        "processor_run.failed",
        "workflow.created",
        "workflow.deployed",
        "workflow.deleted",
        "processor.created",
        "processor.updated",
        "processor.deleted",
        "processor.draft.updated",
        "processor.version.published",
        "parser_run.processed",
        "parser_run.failed",
    ],
    typing.Any,
]
