# This file was auto-generated by Fern from our API Definition.

import typing

ExtractChunkingOptionsChunkSelectionStrategy = typing.Union[
    typing.Literal["intelligent", "confidence", "take_first", "take_last"], typing.Any
]
