# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventWorkflowEventType = typing.Union[
    typing.Literal["workflow.created", "workflow.deployed", "workflow.deleted"], typing.Any
]
