# This file was auto-generated by Fern from our API Definition.

import typing

ClassificationConfigBaseProcessor = typing.Union[
    typing.Literal["classification_performance", "classification_light"], typing.Any
]
