# This file was auto-generated by Fern from our API Definition.

import typing

StepRunOutputRulesItemFailureReason = typing.Union[
    typing.Literal["RULE_FAILED", "PARSE_ERROR", "VALUE_ERROR"], typing.Any
]
