# This file was auto-generated by Fern from our API Definition.

import typing

from .provided_fields_array_output import ProvidedFieldsArrayOutput
from .provided_json_output import ProvidedJsonOutput

ProvidedExtractionOutput = typing.Union[ProvidedJsonOutput, ProvidedFieldsArrayOutput]
