# This file was auto-generated by Fern from our API Definition.

import typing

BadRequestErrorBodyCode = typing.Union[
    typing.Literal["FILE_TYPE_NOT_SUPPORTED", "FILE_SIZE_TOO_LARGE", "CORRUPT_FILE", "PASSWORD_PROTECTED_FILE"],
    typing.Any,
]
